/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const newzpaper_section_lists = ['breakingnews_section','hero_post_section','post_tab_section','podcast_section','author_section','latest_post_section'];
	newzpaper_section_lists.forEach( newzpaper_homepage_scroll_preview );

    function newzpaper_homepage_scroll_preview(item, index) {
    	// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {
			
			// Initially hide the theme option placeholders on load.
			$( '.panel-placeholder' ).hide();

			wp.customize.preview.bind( item, function( data ) {
				// Only on the front page.
				if ( ! $( 'body' ).hasClass( 'home' ) ) {
					return;
				}

				// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
				if ( true === data.expanded ) {
					var elem = document.getElementById("newzpaper_" + item );
                	elem.scrollIntoView();
				} 
			});

		});
 	}
	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'newzpaper_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'newzpaper_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'newzpaper_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-light colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'newzpaper_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );


	// header
	wp.customize( 'newzpaper_theme_options[header_nav_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-one' ).css( 'background-color', to );
			$( '#top-navigation' ).css( 'background-color', to );
			$( '.header-two #site-navigation.main-navigation' ).css( 'background-color', to );
			$( '.main-header' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[header_separator_color]', function( value ) {
		value.bind( function( to ) {
			$( '#masthead.header-three .main-navigation' ).css( 'border-top', '1px solid ' + to );
			$( '#masthead.header-three .main-navigation' ).css( 'border-bottom', '1px solid ' + to );

		} );
	} );

	wp.customize( 'newzpaper_theme_options[header_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation a, .main-navigation ul.nav-menu > li > a, .main-navigation form.search-form ::-webkit-input-placeholder' ).css( 'color', to );
			$( '.main-navigation .social-icons ul li a svg' ).css( 'fill', to );
			$( '#top-navigation .posted-on' ).css( 'color', to );
			$( '.main-navigation form.search-form svg.icon-search, .main-navigation .nav-menu > li > a > svg.icon-down, .search-menu svg.icon-search' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[header_search_bg]', function( value ) {
		value.bind( function( to ) {
			$( '.header-two .main-navigation form.search-form input' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[header_overlay_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-two .header-overlay' ).css( 'background-color', to );
		} );
	} );


	wp.customize( 'newzpaper_theme_options[header_icon_color]', function( value ) {
		value.bind( function( to ) {
			$( '.header-two .main-navigation ul.nav-menu > li.home-icon > a > svg' ).css( 'fill', to );
		} );
	} );



	wp.customize( 'newzpaper_theme_options[header_bg_image]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-two .header-image' ).css( { 'background-image': 'url(' + to + ')', 'background-repeat': 'no-repeat', 'background-size': 'cover', 'background-position': 'center' } );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[header_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.header-two .header-image' ).css( 'padding-top', to + 'px' );
			$( '.header-two .header-image' ).css( 'padding-bottom', to + 'px' );
		} );
	} );



	// end header



	// breakingnews 

	wp.customize( 'newzpaper_theme_options[breakingnews_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_label_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_label_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .news-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_row_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .highlights-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .marquee-content .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .section-title' ).text( to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_label]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights .news-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newzpaper_theme_options[breakingnews_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[breakingnews_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_highlights' ).css( 'padding-bottom', to + 'px' );
		} );
	} );


	// end breakingnews

	// hero post 

	wp.customize( 'newzpaper_theme_options[hero_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_hero_post .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[hero_post_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_hero_post' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[hero_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_hero_post .entry-meta span, #newzpaper_hero_post .entry-meta span a, #newzpaper_hero_post .entry-content p' ).css( 'color', to );
			$( '#newzpaper_hero_post ul.post-categories li a' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[hero_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_hero_post' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[hero_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_hero_post' ).css( 'padding-bottom', to + 'px' );
		} );
	} );


	// end hero post


	// Post Tab

	wp.customize( 'newzpaper_theme_options[post_tab_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_view_more_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .view-all a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_post_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .tabs li a, #newzpaper_magazine .section-tabs span,	#newzpaper_magazine .post-meta, #newzpaper_magazine .entry-meta span, #newzpaper_magazine .entry-meta span a, #newzpaper_magazine .post-meta span a, #newzpaper_magazine .entry-content p' ).css( 'color', to );
			$( '#newzpaper_magazine ul.post-categories li a, #newzpaper_magazine .tabs li a' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_post_card_border_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine article' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .section-title' ).text( to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[post_tab_label]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_magazine .view-all a' ).text( to );
		} );
	} );


	// End Post Tab

	// latest post

	wp.customize( 'newzpaper_theme_options[latest_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.second-design #newzpaper_latest_post_section .section-title, #newzpaper_latest_post_section .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_post_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.second-design #newzpaper_latest_post_section .entry-meta > span:not(:first-child):before, #newzpaper_latest_post_section .entry-meta span, #newzpaper_latest_post_section .entry-meta span a, #newzpaper_latest_post_section .entry-content p' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_separator_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_video_news article:not(:last-child)' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[latest_post_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_latest_post_section .section-title' ).text( to );
		} );
	} );

	// end latest post


	// author

	wp.customize( 'newzpaper_theme_options[author_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_separator_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors article' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.second-design #newzpaper_top_authors .section-title, #newzpaper_top_authors .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_post_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors .entry-title a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_post_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.second-design #newzpaper_top_authors .entry-meta > span:not(:first-child):before, #newzpaper_top_authors .entry-meta span, #newzpaper_top_authors .entry-meta span a' ).css( 'color', to );
			$( '#newzpaper_author ul.post-categories li a' ).css( 'border-color', to );
		} );
	} );


	wp.customize( 'newzpaper_theme_options[author_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors .section-title' ).text( to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[author_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_top_authors' ).css( 'padding-right', to + 'px' );
		} );
	} );

	// end author

	// subscription section
	wp.customize( 'newzpaper_theme_options[subscription_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_input_field_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .jetpack_subscription_widget input[type="email"]' ).css( 'background-color', to );
		} );
	} );


	wp.customize( 'newzpaper_theme_options[subscription_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .entry-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_btn_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .jetpack_subscription_widget button' ).css( 'background-color', to );
			$( '#newzpaper_subscribe .jetpack_subscription_widget button' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_btn_text]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .jetpack_subscription_widget button' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe' ).css( 'padding-bottom', to + 'px' );
		} );
	} );


	wp.customize( 'newzpaper_theme_options[subscription_title]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .entry-title' ).text( to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[subscription_btn_label]', function( value ) {
		value.bind( function( to ) {		
			$( '#newzpaper_subscribe .jetpack_subscription_widget button' ).text( to );
		} );
	} );

	// end subscription section

	
	// single post/page 
	wp.customize( 'newzpaper_theme_options[single_post_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'newzpaper_theme_options[single_post_related_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'newzpaper_theme_options[single_post_entry_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'newzpaper_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'background-color', to );
		} );
	} );
	wp.customize( 'newzpaper_theme_options[single_post_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper, .page #inner-content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_related_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #related-post' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_comment_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper #comments' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[single_post_entry_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.single #inner-content-wrapper .entry-container.post-content' ).css( 'padding', to + 'px' );
		} );
	} );
	// end single post/page

	// widget 
	wp.customize( 'newzpaper_theme_options[widget_panel_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages, #right-sidebar' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget, #right-sidebar .widget' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages,  #right-sidebar' ).css( 'padding-right', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_container_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget,  #right-sidebar .widget' ).css( 'padding', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .wp-block-latest-comments__comment-meta,#secondary.inner-pages .entry-meta > span, #secondary.inner-pages p .about-us-post .entry-title, #secondary.inner-pages p, #secondary.inner-pages a, #secondary.inner-pages .widget h2, #secondary.inner-pages .widget ul li a, #secondary.inner-pages .widget .wp-block-search__label, #right-sidebar .widget ul li a, #right-sidebar .widget .wp-block-search__label, #right-sidebar .widget h2, #right-sidebar .widget .post-number, #right-sidebar .widget .min-read, #right-sidebar a, #right-sidebar p, #right-sidebar p .about-us-post .entry-title, #right-sidebar.inner-pages .wp-block-latest-comments__comment-meta, #right-sidebar.inner-pages .entry-meta > span' ).css( 'color', to );
			$( '#right-sidebar .widget_post_list_three ul.post-categories li a, #left-sidebar .widget_post_list_three ul.post-categories li a, #secondary .widget_post_list_three ul.post-categories li a' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[widget_post_content_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#secondary.inner-pages .widget ul li .entry-container,  #right-sidebar .widget ul li .entry-container' ).css( 'background-color', to );
		} );
	} );

	

	// end widget

	// homepage
	wp.customize( 'newzpaper_theme_options[homepage_section_gap]', function( value ) {
		value.bind( function( to ) {		
			$( '.home-section' ).css( 'margin', to + 'px ' + '0px' );
			$( '#main-post-wrapper main div:first-child, #main-post-wrapper main div:last-child' ).css( 'margin-top', '0px' );
			$( '.right-sidebar #primary, .left-sidebar #primary' ).css( 'paddingright', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[homepage_main_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[homepage_main_container_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[homepage_main_container_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[homepage_main_container_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[homepage_main_container_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #main-post-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );



	//end homepage

	// slider news 
	wp.customize( 'newzpaper_theme_options[slider_news_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_slider_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #newzpaper_slider_news_section' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_section_title_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_section_title_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper .section-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[slider_news_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper' ).css( 'padding-right', to + 'px' );
		} );
	} );
	wp.customize( 'newzpaper_theme_options[slider_news_slider_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '.home #content-wrapper #newzpaper_slider_news_section' ).css( 'padding', to + 'px' );
		} );
	} );
	// end slider news 

	// Archive Page 

	wp.customize( 'newzpaper_theme_options[archive_container_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[archive_post_cotainer_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive .entry-container' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[archive_top_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-top', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[archive_bottom_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-bottom', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[archive_left_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-left', to + 'px' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[archive_right_padding]', function( value ) {
		value.bind( function( to ) {		
			$( '#inner-content-wrapper.archive' ).css( 'padding-right', to + 'px' );
		} );
	} );

	// End Archive 

	// Layout 

	wp.customize( 'newzpaper_theme_options[wrapper_width]', function( value ) {
		value.bind( function( to ) {		
			$( '.wrapper' ).css( 'width', to + '%' );
			$( '#masthead.wrapper' ).css( 'width', to + '%' );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[wrapper_max_width]', function( value ) {
		value.bind( function( to ) {		
			$( '.wrapper' ).css( 'max-width', to + 'px' );
		} );
	} );

	// End Layout 

	// Footer 

	wp.customize( 'newzpaper_theme_options[footer_bg_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[footer_text_color]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon ul li a, #colophon .textwidget p, .site-info span, #colophon .site-info a' ).css( 'color', to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[footer_separator_color]', function( value ) {
		value.bind( function( to ) {		
			$( '.footer-widgets-area .wrapper' ).css( 'border-bottom', '1px solid ' + to );
		} );
	} );

	wp.customize( 'newzpaper_theme_options[footer_top_margin]', function( value ) {
		value.bind( function( to ) {		
			$( '#colophon' ).css( 'margin-top', to + 'px' );
		} );
	} );
	// end footer


} )( jQuery );
