<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

if ( ! function_exists( 'newzpaper_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Newzpaper 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function newzpaper_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'newzpaper_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'newzpaper_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Newzpaper 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function newzpaper_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'newzpaper_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'newzpaper_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Newzpaper 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function newzpaper_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'newzpaper_theme_options[pagination_enable]' )->value();
	}
endif;



if ( ! function_exists( 'newzpaper_is_breakingnews_section_enable' ) ) :

	function newzpaper_is_breakingnews_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[breakingnews_section_enable]' )->value() );
	}
endif;


if ( ! function_exists( 'newzpaper_is_breakingnews_slider_section_enable' ) ) :

	function newzpaper_is_breakingnews_slider_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[slider_section_enable]' )->value() );
	}
endif;


if ( ! function_exists( 'newzpaper_is_hero_post_section_enable' ) ) :

	function newzpaper_is_hero_post_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[hero_post_section_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'newzpaper_is_hero_post_section_content_page_enable' ) ) :

	function newzpaper_is_hero_post_section_content_page_enable( $control ) {
		$content_type = $control->manager->get_setting( 'newzpaper_theme_options[hero_post_content_type]' )->value();
		return newzpaper_is_hero_post_section_enable( $control ) && ( 'page' == $content_type );
	}
endif;


if ( ! function_exists( 'newzpaper_is_hero_post_section_content_post_enable' ) ) :

	function newzpaper_is_hero_post_section_content_post_enable( $control ) {
		$content_type = $control->manager->get_setting( 'newzpaper_theme_options[hero_post_content_type]' )->value();
		return newzpaper_is_hero_post_section_enable( $control ) && ( 'post' == $content_type );
	}
endif;


if ( ! function_exists( 'newzpaper_is_post_tab_section_enable' ) ) :

	function newzpaper_is_post_tab_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[post_tab_section_enable]' )->value() );
	}
endif;


if ( ! function_exists( 'newzpaper_is_latest_post_section_enable' ) ) :

	function newzpaper_is_latest_post_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[latest_post_section_enable]' )->value() );
	}
endif;


if ( ! function_exists( 'newzpaper_is_author_section_enable' ) ) :

	function newzpaper_is_author_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[author_section_enable]' )->value() );
	}
endif;


if ( ! function_exists( 'newzpaper_is_author_section_content_category_enable' ) ) :

	function newzpaper_is_author_section_content_category_enable( $control ) {
		$content_type = $control->manager->get_setting( 'newzpaper_theme_options[author_content_type]' )->value();
		return newzpaper_is_author_section_enable( $control ) && ( 'category' == $content_type );
	}
endif;

if ( ! function_exists( 'newzpaper_is_author_section_content_post_enable' ) ) :

	function newzpaper_is_author_section_content_post_enable( $control ) {
		$content_type = $control->manager->get_setting( 'newzpaper_theme_options[author_content_type]' )->value();
		return newzpaper_is_author_section_enable( $control ) && ( 'post' == $content_type );
	}
endif;

if ( ! function_exists( 'newzpaper_is_subscription_section_enable' ) ) :

	function newzpaper_is_subscription_section_enable( $control ) {
		return ( $control->manager->get_setting( 'newzpaper_theme_options[subscription_section_enable]' )->value() );
	}
endif;

