<?php
/**
 * Newzpaper Customizer.
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function newzpaper_customize_register( $wp_customize ) {
	$options = newzpaper_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';


	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'newzpaper_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'newzpaper_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'newzpaper' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'newzpaper_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'newzpaper_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'newzpaper' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'newzpaper_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'newzpaper_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'newzpaper_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'newzpaper' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'newzpaper' ),
			'show-all'     => esc_html__( 'Show All', 'newzpaper' ),
			'title-only'   => esc_html__( 'Title Only', 'newzpaper' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'newzpaper' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'newzpaper' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'newzpaper' ),
			)
	) );


	// Add panel for common theme options
	$wp_customize->add_panel( 'newzpaper_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','newzpaper' ),
	    'description'=> esc_html__( 'Newzpaper Theme Options.', 'newzpaper' ),
	    'priority'   => 150,
	) );

	// header
	require get_template_directory() . '/inc/customizer/theme-options/header.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/header.php';

	// page banner
	require get_template_directory() . '/inc/customizer/theme-options/page-banner.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/single-post.php';

	require get_template_directory() . '/inc/customizer/theme-options/style/widget.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';
	require get_template_directory() . '/inc/customizer/theme-options/style/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'newzpaper_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','newzpaper' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'newzpaper' ),
	    'priority'   => 140,
	) );

	require get_template_directory() . '/inc/customizer/sections/home-layout.php';


	// load breakingnews option
	require get_template_directory() . '/inc/customizer/sections/breakingnews.php';	
	require get_template_directory() . '/inc/customizer/sections/style/breakingnews.php';	

	// load hero post news option
	require get_template_directory() . '/inc/customizer/sections/hero-post.php';	
	require get_template_directory() . '/inc/customizer/sections/style/hero-post.php';


	// load post tab option
	require get_template_directory() . '/inc/customizer/sections/post-tab.php';	
	require get_template_directory() . '/inc/customizer/sections/style/post-tab.php';

	// load latest post option
	require get_template_directory() . '/inc/customizer/sections/latest-post.php';
	require get_template_directory() . '/inc/customizer/sections/style/latest-post.php';

	// load author option
	require get_template_directory() . '/inc/customizer/sections/author.php';
	require get_template_directory() . '/inc/customizer/sections/style/author.php';

	// load have-missed option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';
	require get_template_directory() . '/inc/customizer/sections/style/subscription.php';
	
	
}
add_action( 'customize_register', 'newzpaper_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function newzpaper_customize_preview_js() {
	wp_enqueue_script( 'newzpaper-customizer', get_template_directory_uri() . '/assets/js/customizer' . newzpaper_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'newzpaper_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function newzpaper_customize_control_js() {
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . newzpaper_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . newzpaper_min() . '.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_style( 'newzpaper-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . newzpaper_min() . '.css' );
	wp_enqueue_script( 'newzpaper-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . newzpaper_min() . '.js', array(), '1.0', true );
	$newzpaper_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'newzpaper' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'newzpaper-customize-controls', 'newzpaper_reset_data', $newzpaper_reset_data );

	$theme_path_url = array( 'url' => get_theme_file_uri() );

	wp_localize_script( 'newzpaper-customize-controls', 'theme_url', $theme_path_url );
}
add_action( 'customize_controls_enqueue_scripts', 'newzpaper_customize_control_js' );

if ( !function_exists( 'newzpaper_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Newzpaper 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function newzpaper_reset_options() {
		$options = newzpaper_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'newzpaper_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'newzpaper_reset_options' );
