<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 * @return array An array of default values
 */

function newzpaper_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$newzpaper_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#e5383e',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'lite-version',
		'header_overlay_color'			=> '#000',
		'header_overlay'				=> 5,
		'home_layout'					=> 'default-layout',
		'home_design'					=> 'default-design',
		'header_absolute_enable'		=> true,
		'homepage_section_gap'			=> 10,
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'bg_image'						=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'widget_enable_sticky_homepage' => false,
		'transparent_menu' 				=> false,
		'widget_enable_sticky' 			=> false,


		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'newzpaper' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'numeric',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'newzpaper' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'newzpaper' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'newzpaper' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_wrapper_enable'			=> false,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		'default_sortable'	=> 'breakingnews,hero_post,post_tab,main_content,author,subscription',
		'default_inner_sortable'	=> 'latest_post',


		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'newzpaper' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,
		'single_post_hide_post_title'   => false,
		'single_post_hide_featured_image'   => false,

		'page_banner_wrapper_enable'	=> false,
		'page_banner_breadcrumb_enable'	=> false,
		'page_banner_header_image_enable'	=> false,

		/* Front Page */

		// Header
		'header_design'				=> 'header-one',
		'social_nav_enable' 		=> false,

		// Breaking News
		'breakingnews_section_enable'			=> false,
		'breakingnews_featured_image_enable'	=> false,
		'breakingnews_title'					=> esc_html__( 'Hot News', 'newzpaper' ),
		'breakingnews_label'					=> esc_html__( 'Live Report', 'newzpaper' ),

		// Hero Post
		'hero_post_section_enable'			=> false,

		// Post Tab 
		'post_tab_section_enable'			=> false,
		'post_tab_title'					=> esc_html__( 'MAGAZINE', 'newzpaper' ),
		'post_tab_label'					=> esc_html__( 'All Articles', 'newzpaper' ),

		// latest Post
		'latest_post_section_enable'		=> false,
		'latest_post_title'					=> esc_html__( 'Latest News', 'newzpaper' ),
		'latest_post_content_excerpt'		=> 90,

		
		// author
		'author_section_enable'		=> false,
		'author_title'					=> esc_html__( 'Top Author', 'newzpaper' ),
		'author_count'					=> 4,

		// Subscription 
		'subscription_section_enable'  => false,
		'subscription_title'	=> esc_html__( 'SUBSCRIBE TO OUR NEWSLETTER', 'newzpaper' ),
		'subscription_btn_label'	=> esc_html__( 'Send Now', 'newzpaper' ),
	);

	$output = apply_filters( 'newzpaper_default_theme_options', $newzpaper_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}