<?php
/**
* Author Section options
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/

// Add Author section
$wp_customize->add_section( 'newzpaper_author_section', array(
    'title'             => esc_html__( 'Author','newzpaper' ),
    'description'       => esc_html__( 'Author Section options.', 'newzpaper' ),
    'panel'             => 'newzpaper_front_page_panel',
    ) );

// Author content enable control and setting
$wp_customize->add_setting( 'newzpaper_theme_options[author_section_enable]', array(
    'default'           =>  $options['author_section_enable'],
    'sanitize_callback' => 'newzpaper_sanitize_switch_control',
    ) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[author_section_enable]', array(
    'label'             => esc_html__( 'Author Section Enable', 'newzpaper' ),
    'section'           => 'newzpaper_author_section',
    'on_off_label'      => newzpaper_switch_options(),
    ) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'newzpaper_theme_options[author_section_enable]',
        array(
            'selector'            => '#newzpaper_author_section .tooltiptext',
            'settings'            => 'newzpaper_theme_options[author_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'newzpaper_theme_options_author_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Newzpaper_Customize_Control_Section_Style( 
    $wp_customize,
    'newzpaper_theme_options_author_setting_style',
        array(
            'section'       => 'newzpaper_author_section',
            'active_callback'   => 'newzpaper_is_author_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'newzpaper' ),
                    'section_id' => 'newzpaper_author_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'newzpaper' ),
                    'section_id' => 'newzpaper_author_section_style',
                ),
            ),
        )
    )
);

// author title setting and control
$wp_customize->add_setting( 'newzpaper_theme_options[author_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['author_title'],
    'transport'         => 'postMessage',
    ) );

$wp_customize->add_control( 'newzpaper_theme_options[author_title]', array(
    'label'             => esc_html__( 'Section Title', 'newzpaper' ),
    'section'           => 'newzpaper_author_section',
    'active_callback'   => 'newzpaper_is_author_section_enable',
    'type'              => 'text',
    ) );



for ( $i = 1; $i <= 4; $i++ ) :
    $wp_customize->add_setting( 'newzpaper_theme_options[author_name_'.$i.']', array(
        'sanitize_callback' => 'sanitize_text_field',
        ) );

    $wp_customize->add_control( 'newzpaper_theme_options[author_name_'.$i.']', array(
        'label'             => esc_html__( 'Author Name ', 'newzpaper' ).$i,
        'section'           => 'newzpaper_author_section',
        'active_callback'   => 'newzpaper_is_author_section_enable',
        'type'              => 'text',
        ) );

    $wp_customize->add_setting( 'newzpaper_theme_options[author_url_'.$i.']',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control( 'newzpaper_theme_options[author_url_'.$i.']',
        array(
            'label'             => esc_html__( 'Author URL ', 'newzpaper' ).$i,
            'section'           => 'newzpaper_author_section',
            'active_callback'   => 'newzpaper_is_author_section_enable',
            'type'              => 'url',
        ) 
    );

    $wp_customize->add_setting( 'newzpaper_theme_options[author_image_' . $i . ']', array(
        'sanitize_callback' => 'newzpaper_sanitize_image'
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'newzpaper_theme_options[author_image_' . $i . ']',
            array(
            'label'             => sprintf( esc_html__( ' Author Image %d', 'newzpaper' ), $i ),
            'section'           => 'newzpaper_author_section',
            'active_callback'   => 'newzpaper_is_author_section_enable',
    ) ) );


    $wp_customize->add_setting( 'newzpaper_theme_options[author_position_'.$i.']', array(
        'sanitize_callback' => 'sanitize_text_field',
        ) );

    $wp_customize->add_control( 'newzpaper_theme_options[author_position_'.$i.']', array(
        'label'             => esc_html__( 'Author Position ', 'newzpaper' ).$i,
        'section'           => 'newzpaper_author_section',
        'active_callback'   => 'newzpaper_is_author_section_enable',
        'type'              => 'text',
        ) );

    $wp_customize->add_setting( 'newzpaper_theme_options[author_location_'.$i.']', array(
        'sanitize_callback' => 'sanitize_text_field',
        ) );

    $wp_customize->add_control( 'newzpaper_theme_options[author_location_'.$i.']', array(
        'label'             => esc_html__( 'Author Location ', 'newzpaper' ).$i,
        'section'           => 'newzpaper_author_section',
        'active_callback'   => 'newzpaper_is_author_section_enable',
        'type'              => 'text',
        ) );

    $wp_customize->add_setting( 'newzpaper_theme_options[author_separator_'.$i.']', array(
        'sanitize_callback' => 'sanitize_text_field', 
    ) );


    $wp_customize->add_control( new Newzpaper_Customize_Horizontal_Line( $wp_customize, 'newzpaper_theme_options[author_separator_'.$i.']', array(
         'section'           => 'newzpaper_author_section',
        'active_callback'  => 'newzpaper_is_author_section_enable',
        'type'            => 'hr'
    ) ) );


endfor;
