<?php
/**
* Latest Post Section options
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/

// Add Latest Post section
$wp_customize->add_section( 'newzpaper_latest_post_section', array(
	'title'             => esc_html__( 'Latest Post','newzpaper' ),
	'description'       => esc_html__( 'Latest Post Section options.', 'newzpaper' ),
	'panel'             => 'newzpaper_front_page_panel',
	) );

// Latest Post content enable control and setting
$wp_customize->add_setting( 'newzpaper_theme_options[latest_post_section_enable]', array(
	'default'			=> 	$options['latest_post_section_enable'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
	) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[latest_post_section_enable]', array(
	'label'             => esc_html__( 'Latest Post Section Enable', 'newzpaper' ),
	'section'           => 'newzpaper_latest_post_section',
	'on_off_label' 		=> newzpaper_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'newzpaper_theme_options[latest_post_section_enable]',
        array(
            'selector'            => '#newzpaper_latest_post_section .tooltiptext',
            'settings'            => 'newzpaper_theme_options[latest_post_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'newzpaper_theme_options_latest_post_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Newzpaper_Customize_Control_Section_Style( 
    $wp_customize,
    'newzpaper_theme_options_latest_post_setting_style',
        array(
            'section'       => 'newzpaper_latest_post_section',
            'active_callback' 	=> 'newzpaper_is_latest_post_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'newzpaper' ),
                    'section_id' => 'newzpaper_latest_post_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'newzpaper' ),
                    'section_id' => 'newzpaper_latest_post_section_style',
                ),
            ),
        )
    )
);

// latest_post title setting and control
$wp_customize->add_setting( 'newzpaper_theme_options[latest_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_post_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newzpaper_theme_options[latest_post_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'newzpaper' ),
	'section'        	=> 'newzpaper_latest_post_section',
	'active_callback' 	=> 'newzpaper_is_latest_post_section_enable',
	'type'				=> 'text',
	) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'newzpaper_theme_options[latest_post_content_category]', array(
	'sanitize_callback' => 'newzpaper_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Newzpaper_Dropdown_Category_Control( $wp_customize,'newzpaper_theme_options[latest_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'newzpaper' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'newzpaper' ),
	'section'           => 'newzpaper_latest_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'newzpaper_is_latest_post_section_enable'
	) ) );

