<?php
/**
* Post Tab Section options
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/

// Add Post Tab section
$wp_customize->add_section( 'newzpaper_post_tab_section', array(
	'title'             => esc_html__( 'Post Tab','newzpaper' ),
	'description'       => esc_html__( 'Post Tab Section options.', 'newzpaper' ),
	'panel'             => 'newzpaper_front_page_panel',
	) );

// Post Tab content enable control and setting
$wp_customize->add_setting( 'newzpaper_theme_options[post_tab_section_enable]', array(
	'default'			=> 	$options['post_tab_section_enable'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
	) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[post_tab_section_enable]', array(
	'label'             => esc_html__( 'Post Tab Section Enable', 'newzpaper' ),
	'section'           => 'newzpaper_post_tab_section',
	'on_off_label' 		=> newzpaper_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'newzpaper_theme_options[post_tab_section_enable]',
		array(
			'selector'            => '#newzpaper_post_tab_section .tooltiptext',
			'settings'            => 'newzpaper_theme_options[post_tab_section_enable]',
		)
	);
}

$wp_customize->add_setting( 
    'newzpaper_theme_options_post_tab_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Newzpaper_Customize_Control_Section_Style( 
    $wp_customize,
    'newzpaper_theme_options_post_tab_setting_style',
        array(
            'section'       => 'newzpaper_post_tab_section',
            'active_callback' 	=> 'newzpaper_is_post_tab_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'newzpaper' ),
                    'section_id' => 'newzpaper_post_tab_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'newzpaper' ),
                    'section_id' => 'newzpaper_post_tab_section_style',
                ),
            ),
        )
    )
);


// post_tab title setting and control
$wp_customize->add_setting( 'newzpaper_theme_options[post_tab_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['post_tab_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newzpaper_theme_options[post_tab_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'newzpaper' ),
	'section'        	=> 'newzpaper_post_tab_section',
	'active_callback' 	=> 'newzpaper_is_post_tab_section_enable',
	'type'				=> 'text',
	) );

$wp_customize->add_setting( 'newzpaper_theme_options[post_tab_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['post_tab_label'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newzpaper_theme_options[post_tab_label]', array(
	'label'           	=> esc_html__( 'View More Btn Label', 'newzpaper' ),
	'section'        	=> 'newzpaper_post_tab_section',
	'active_callback' 	=> 'newzpaper_is_post_tab_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'newzpaper_theme_options[post_tab_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'newzpaper_theme_options[post_tab_btn_url]',
    array(
        'label'           	=> esc_html__( 'View More Btn URL', 'newzpaper' ),
        'section'        	=> 'newzpaper_post_tab_section',
        'active_callback' 	=> 'newzpaper_is_post_tab_section_enable',
        'type'				=> 'url',
    ) 
);

$wp_customize->add_setting( 'newzpaper_theme_options[post_tab_category]',
    array(
        'sanitize_callback' => 'newzpaper_sanitize_category_list',
    )
);

$wp_customize->add_control( new Newzpaper_Dropdown_Multiple_Chooser( $wp_customize,
		'newzpaper_theme_options[post_tab_category]', 
		array(
			'label'             => esc_html__( 'Select Including Categories', 'newzpaper' ),
			'section'           => 'newzpaper_post_tab_section',
			'type'              => 'dropdown_multiple_chooser',
			'active_callback' 	=> 'newzpaper_is_post_tab_section_enable',
			'choices'           =>  newzpaper_category_choices(),
		)
	)
);