<?php
/**
* Subscription Section options
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/

// Add Subscription section
$wp_customize->add_section( 'newzpaper_subscription_section', array(
	'title'             => esc_html__( 'Subscription','newzpaper' ),
	'description'       => esc_html__( 'Subscription Section options.', 'newzpaper' ),
	'panel'             => 'newzpaper_front_page_panel',
	) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'newzpaper_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
	) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'newzpaper' ),
	'section'           => 'newzpaper_subscription_section',
	'on_off_label' 		=> newzpaper_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'newzpaper_theme_options[subscription_section_enable]',
        array(
            'selector'            => '#newzpaper_subscription_section .tooltiptext',
            'settings'            => 'newzpaper_theme_options[subscription_section_enable]',
        )
    );
}

$wp_customize->add_setting( 
    'newzpaper_theme_options_subscription_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Newzpaper_Customize_Control_Section_Style( 
    $wp_customize,
    'newzpaper_theme_options_subscription_setting_style',
        array(
            'section'       => 'newzpaper_subscription_section',
            'active_callback' 	=> 'newzpaper_is_subscription_section_enable',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'newzpaper' ),
                    'section_id' => 'newzpaper_subscription_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'newzpaper' ),
                    'section_id' => 'newzpaper_subscription_section_style',
                ),
            ),
        )
    )
);

// subscription title setting and control
$wp_customize->add_setting( 'newzpaper_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newzpaper_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'newzpaper' ),
	'section'        	=> 'newzpaper_subscription_section',
	'active_callback' 	=> 'newzpaper_is_subscription_section_enable',
	'type'				=> 'text',
	) );



// subscription title setting and control
$wp_customize->add_setting( 'newzpaper_theme_options[subscription_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_label'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newzpaper_theme_options[subscription_btn_label]', array(
	'label'           	=> esc_html__( 'Btn Label', 'newzpaper' ),
	'section'        	=> 'newzpaper_subscription_section',
	'active_callback' 	=> 'newzpaper_is_subscription_section_enable',
	'type'				=> 'text',
	) );

