<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'newzpaper_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','newzpaper' ),
	'description'       => esc_html__( 'Archive section options.', 'newzpaper' ),
	'panel'             => 'newzpaper_theme_options_panel',
) );

$wp_customize->add_setting( 
    'newzpaper_theme_options_archive_setting_style',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 
    new Newzpaper_Customize_Control_Section_Style( 
    $wp_customize,
    'newzpaper_theme_options_archive_setting_style',
        array(
            'section'       => 'newzpaper_archive_section',
            'choices'  => array(

                'setting'    => array(
                    'name' => esc_html__( 'Setting', 'newzpaper' ),
                    'section_id' => 'newzpaper_archive_section',
                ),
                
                'style'    => array(
                    'name' => esc_html__( 'Style', 'newzpaper' ),
                    'section_id' => 'newzpaper_archive_section_style',
                ),
            ),
        )
    )
);

// Your latest posts title setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'newzpaper_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'newzpaper' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'newzpaper' ),
	'section'           => 'newzpaper_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'newzpaper_is_latest_posts'
) );

// Archive category setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'newzpaper' ),
	'section'           => 'newzpaper_archive_section',
	'on_off_label' 		=> newzpaper_hide_options(),
) ) );

// Archive date setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'newzpaper' ),
	'section'           => 'newzpaper_archive_section',
	'on_off_label' 		=> newzpaper_hide_options(),
) ) );

// Archive author setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[hide_author]', array(
	'default'           => $options['hide_author'],
	'sanitize_callback' => 'newzpaper_sanitize_switch_control',
) );

$wp_customize->add_control( new Newzpaper_Switch_Control( $wp_customize, 'newzpaper_theme_options[hide_author]', array(
	'label'             => esc_html__( 'Hide Author', 'newzpaper' ),
	'section'           => 'newzpaper_archive_section',
	'on_off_label' 		=> newzpaper_hide_options(),
) ) );