<?php
/**
 * Layout options
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'newzpaper_layout', array(
	'title'               => esc_html__('Layout','newzpaper'),
	'description'         => esc_html__( 'Layout section options.', 'newzpaper' ),
	'panel'               => 'newzpaper_theme_options_panel',
) );

// Site layout setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[site_layout]', array(
	'sanitize_callback'   => 'newzpaper_sanitize_select',
	'default'             => $options['site_layout'],
) );

$wp_customize->add_control(  new Newzpaper_Custom_Radio_Image_Control ( $wp_customize, 'newzpaper_theme_options[site_layout]', array(
	'label'               => esc_html__( 'Site Layout', 'newzpaper' ),
	'section'             => 'newzpaper_layout',
	'choices'			  => newzpaper_site_layout(),
) ) );

// Sidebar position setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[sidebar_position]', array(
	'sanitize_callback'   => 'newzpaper_sanitize_select',
	'default'             => $options['sidebar_position'],
) );

$wp_customize->add_control(  new Newzpaper_Custom_Radio_Image_Control ( $wp_customize, 'newzpaper_theme_options[sidebar_position]', array(
	'label'               => esc_html__( 'Global Sidebar Position', 'newzpaper' ),
	'section'             => 'newzpaper_layout',
	'choices'			  => newzpaper_global_sidebar_position(),
) ) );

// Post sidebar position setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[post_sidebar_position]', array(
	'sanitize_callback'   => 'newzpaper_sanitize_select',
	'default'             => $options['post_sidebar_position'],
) );

$wp_customize->add_control(  new Newzpaper_Custom_Radio_Image_Control ( $wp_customize, 'newzpaper_theme_options[post_sidebar_position]', array(
	'label'               => esc_html__( 'Posts Sidebar Position', 'newzpaper' ),
	'section'             => 'newzpaper_layout',
	'choices'			  => newzpaper_sidebar_position(),
) ) );

// Post sidebar position setting and control.
$wp_customize->add_setting( 'newzpaper_theme_options[page_sidebar_position]', array(
	'sanitize_callback'   => 'newzpaper_sanitize_select',
	'default'             => $options['page_sidebar_position'],
) );

$wp_customize->add_control( new Newzpaper_Custom_Radio_Image_Control( $wp_customize, 'newzpaper_theme_options[page_sidebar_position]', array(
	'label'               => esc_html__( 'Pages Sidebar Position', 'newzpaper' ),
	'section'             => 'newzpaper_layout',
	'choices'			  => newzpaper_sidebar_position(),
) ) );


$wp_customize->add_setting( 'newzpaper_theme_options[wrapper_width]', array(
    'sanitize_callback' => 'newzpaper_sanitize_number_range',
    'transport'         => 'postMessage'
    ) );

$wp_customize->add_control( 'newzpaper_theme_options[wrapper_width]', array(
    'label'             => esc_html__( 'Wrapper Width', 'newzpaper' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 100.', 'newzpaper' ),
    'section'           => 'newzpaper_layout',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 100,
        'style' => 'width: 100px;'
        ),
    ) );

$wp_customize->add_setting( 'newzpaper_theme_options[wrapper_max_width]', array(
    'sanitize_callback' => 'newzpaper_sanitize_number_range',
    'transport'         => 'postMessage'
    ) );

$wp_customize->add_control( 'newzpaper_theme_options[wrapper_max_width]', array(
    'label'             => esc_html__( 'Wrapper Max Width', 'newzpaper' ),
    'section'           => 'newzpaper_layout',
    'type'              => 'number',
    ) );