<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function newzpaper_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'newzpaper' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function newzpaper_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'newzpaper' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function newzpaper_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'newzpaper' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}


if ( ! function_exists( 'newzpaper_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function newzpaper_site_layout() {
        $newzpaper_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'newzpaper_site_layout', $newzpaper_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'newzpaper_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function newzpaper_selected_sidebar() {
        $newzpaper_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'newzpaper' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'newzpaper' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'newzpaper' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'newzpaper' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'newzpaper' ),
        );

        $output = apply_filters( 'newzpaper_selected_sidebar', $newzpaper_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'newzpaper_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function newzpaper_global_sidebar_position() {
        $newzpaper_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'newzpaper_global_sidebar_position', $newzpaper_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'newzpaper_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function newzpaper_sidebar_position() {
        $newzpaper_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'newzpaper_sidebar_position', $newzpaper_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'newzpaper_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function newzpaper_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'newzpaper' ),
            'off'       => esc_html__( 'Disable', 'newzpaper' )
        );
        return apply_filters( 'newzpaper_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'newzpaper_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function newzpaper_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'newzpaper' ),
            'off'       => esc_html__( 'No', 'newzpaper' )
        );
        return apply_filters( 'newzpaper_hide_options', $arr );
    }
endif;


function newzpaper_get_post_cat_choices() {
  $choices = array( '' => esc_html__( '--Select--', 'newzpaper' ) );
    $cats = get_categories();
    foreach ( $cats as $cat ) {
        $id = $cat->term_id;
        $title = $cat->name;
        $choices[ $id ] = $title;
    }
    return $choices;
}