<?php
/**
 * Headline section
 *
 * This is the template for the content of breakingnews section
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */
if ( ! function_exists( 'newzpaper_add_breakingnews_section' ) ) :
    /**
    * Add breakingnews section
    *
    *@since Newzpaper 1.0.0
    */
    function newzpaper_add_breakingnews_section() {
    	$options = newzpaper_get_theme_options();
        // Check if breakingnews is enabled on frontpage
        $breakingnews_enable = apply_filters( 'newzpaper_section_status', true, 'breakingnews_section_enable' );

        if ( true !== $breakingnews_enable ) {
            return false;
        }
        // Get breakingnews section details
        $section_details = array();
        $section_details = apply_filters( 'newzpaper_filter_breakingnews_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render breakingnews section now.
        newzpaper_render_breakingnews_section( $section_details );
    }
endif;

if ( ! function_exists( 'newzpaper_get_breakingnews_section_details' ) ) :
    /**
    * breakingnews section details.
    *
    * @since Newzpaper 1.0.0
    * @param array $input breakingnews section details.
    */
    function newzpaper_get_breakingnews_section_details( $input ) {
        $options = newzpaper_get_theme_options();

        $content = array();

        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 5,
            'ignore_sticky_posts'   => true,
            );    

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                   $page_post['image']      = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $page_post['url']       = get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// breakingnews section content details.
add_filter( 'newzpaper_filter_breakingnews_section_details', 'newzpaper_get_breakingnews_section_details' );


if ( ! function_exists( 'newzpaper_render_breakingnews_section' ) ) :
  /**
   * Start breakingnews section
   *
   * @return string breakingnews content
   * @since Newzpaper 1.0.0
   *
   */
function newzpaper_render_breakingnews_section( $content_details = array() ) {
    $options = newzpaper_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="newzpaper_breakingnews_section" class="relative home-section breaking-news">
        <div id="newzpaper_highlights" class="page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    newzpaper_section_tooltip( 'breaking-news-class' );
                endif; ?>
                <?php if ( !empty( $options['breakingnews_title'] ) ): ?>
                     <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['breakingnews_title'] ); ?></h2>
                    </div>
                <?php endif ?>
                <div class="highlights-wrapper ">
                    <?php if ( !empty( $options['breakingnews_label'] ) ): ?>
                        <h2 class="news-title"><?php echo esc_html( $options['breakingnews_label'] ); ?></h2>
                    <?php endif ?>
                    <div class="marquee-content">
                        <ul class="marquee">
                            <?php foreach ( $content_details as $content ) : ?>
                                <li>
                                    <div class="highlights-content">
                                        <?php if ( $options['breakingnews_featured_image_enable'] ): ?>
                                            <div class="featured-image relative">
                                                <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                            </div>
                                        <?php endif ?>                                    
                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        </div><!-- .entry-container -->
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        </ul><!-- section-content -->
                    </div>
                </div>            
            </div>    
        </div>
       
    </div>
    
<?php }
    endif;
