<?php
/**
* Main Slider section
*
* This is the template for the content of hero_post section
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/
if ( ! function_exists( 'newzpaper_add_hero_post_section' ) ) :
/**
* Add hero_post section
*
*@since Newzpaper 1.0.0
*/
function newzpaper_add_hero_post_section() {
    $options = newzpaper_get_theme_options();
    // Check if hero_post is enabled on frontpage
    $hero_post_enable = apply_filters( 'newzpaper_section_status', true, 'hero_post_section_enable' );

    if ( true !== $hero_post_enable ) {
        return false;
    }
    // Get hero_post section details
    $section_details = array();
    $section_details = apply_filters( 'newzpaper_filter_hero_post_section_details', $section_details );

    if ( empty( $section_details ) ) {
        return;
    }

// Render hero_post section now.
    newzpaper_render_hero_post_section( $section_details );
}
endif;

if ( ! function_exists( 'newzpaper_get_hero_post_section_details' ) ) :
/**
* hero_post section details.
*
* @since Newzpaper 1.0.0
* @param array $input hero_post section details.
*/
function newzpaper_get_hero_post_section_details( $input ) {
    $options = newzpaper_get_theme_options();

    $content_details = array();

    $post_id = !empty( $options['hero_post_content_post'] ) ? $options['hero_post_content_post'] : '';

    $args = array(
        'post_type'         => 'post',
        'p'          => $post_id,
        'posts_per_page'    => 1,
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );    
    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['title']     = get_the_title();
        $page_post['content']   = get_the_content();
        $page_post['excerpt']   = newzpaper_trim_content( 100 );
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['url']       = get_the_permalink();
        $page_post['image'] = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

    // Push to the main array.
    array_push( $content_details, $page_post );
    endwhile;
    endif;
    wp_reset_postdata();

    if ( ! empty( $content_details ) ) {
        $input = $content_details;
    }
    return $input;
}
endif;
// hero_post section content details.
add_filter( 'newzpaper_filter_hero_post_section_details', 'newzpaper_get_hero_post_section_details' );


if ( ! function_exists( 'newzpaper_render_hero_post_section' ) ) :
/**
* Start hero_post section
*
* @return string hero_post content
* @since Newzpaper 1.0.0
*
*/
function newzpaper_render_hero_post_section( $content_details = array() ) {
    $options = newzpaper_get_theme_options();
    if ( empty( $content_details ) ) {
      return;
    }
?>
<div id="newzpaper_hero_post_section">
    <div id="newzpaper_hero_post" class="relative home-section hero-post">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                newzpaper_section_tooltip( 'hero-post-class' );
            endif; ?>
            <article>
                <div class="entry-container clear">
                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content_details[0]['url'] ); ?>"><?php echo esc_html( $content_details[0]['title'] ); ?></a></h2>
                    </header>
                    <div class="entry-content">
                        <p><?php echo esc_html( $content_details[0]['excerpt'] ); ?></p>
                        <div class="entry-meta">
                            <?php echo newzpaper_author($content_details[0]['auth_id'] ); ?>
                            <?php newzpaper_posted_on($content_details[0]['id'] ); ?>
                            <span class="min-read"><span class="entry-meta-text"><?php echo esc_html__( 'Read: ', 'newzpaper' ); ?></span> <?php echo newzpaper_time_interval($content_details[0]['content']); echo esc_html__(' min', 'newzpaper'); ?></span>
                            <span class="cat-links">
                              <?php the_category( '', '', $content_details[0]['id'] ); ?>
                          </span>
                        </div>
                    </div>
                </div>
                <div class="featured-image relative">
                    <img src="<?php echo esc_url( $content_details[0]['image'] ); ?>">
                    <div class="overlay"></div>
                </div>
            </article>
        </div>
    </div><!-- #newzpaper_hero_post -->
</div>
  

<?php }
    endif;

