<?php
/**
* featured slider section
*
* This is the template for the content of latest_post section
*
* @package Theme Palace
* @subpackage Newzpaper
* @since Newzpaper 1.0.0
*/

$options = newzpaper_get_theme_options();

if( $options['latest_post_section_enable'] !== false ):

$content_details = array();
$cat_id = ! empty( $options['latest_post_content_category'] ) ? $options['latest_post_content_category'] : '';

$args = array(
    'post_type'         => 'post',
    'posts_per_page'    => 7,
    'category__in'      => ( array ) $cat_id,
    'ignore_sticky_posts'   => true,
    );                    


// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
$page_post['id']        = get_the_id();
$page_post['title']     = get_the_title();
$page_post['auth_id']   = get_the_author_meta('ID');
$page_post['url']       = get_the_permalink();
$page_post['content']   = get_the_content();
$page_post['excerpt']   = wp_trim_words( get_the_content(), $options['latest_post_content_excerpt'], '...' );
$page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
wp_reset_postdata();
?>

<div id="newzpaper_latest_post_section" class="relative home-section latest-post">
    <div id="newzpaper_video_news">
        <?php if ( is_customize_preview()):
            newzpaper_section_tooltip( 'latest-post-class' );
        endif; ?>
        <?php if ( ! empty( $options['latest_post_title'] ) ) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $options['latest_post_title'] ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>
        <div class="section-content">
            <?php foreach ( $content_details as $content ) : ?>
                <article>
                    <div class="video-news-wrapper">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="overlay"></div>
                        </div>

                        <div class="entry-container">
                            
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div>

                            <div class="entry-meta">
                                <?php echo newzpaper_author($content['auth_id'] ); ?>
                                <?php newzpaper_posted_on( $content['id'] ); ?>
                                <span class="min-read"><span class="entry-meta-text"><?php echo esc_html__( 'Read: ', 'newzpaper' ); ?></span> <span><?php echo newzpaper_time_interval($content['content']); echo esc_html__(' min', 'newzpaper'); ?></span></span>
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span>
                            </div>
                           
                        </div>                        
                    </div>
                </article>
            <?php endforeach; ?>            
        </div>
    </div>
</div>

<?php endif; ?>


