<?php
/**
 * Tab section
 *
 * This is the template for the content of tab section
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */
if ( ! function_exists( 'newzpaper_add_post_tab_section' ) ) :
    /**
    * Add tab section
    *
    *@since Newzpaper 1.0.0
    */
    function newzpaper_add_post_tab_section() {
        $options = newzpaper_get_theme_options();

        // Check if tab is enabled on frontpage
        $tab_enable = apply_filters( 'newzpaper_section_status', true, 'post_tab_section_enable' );

        if ( true !== $tab_enable ) {
           return false;
        }
        // Get tab section details
        $section_details = array();
        $section_details = apply_filters( 'newzpaper_filter_post_tab_section_details', $section_details );
        if ( empty( $section_details ) ) {
           return;
        }
        // Render tab section now.
        newzpaper_render_post_tab_section( $section_details );
    }
endif;

if ( ! function_exists( 'newzpaper_get_post_tab_section_details' ) ) :
    /**
    * tab section details.
    *
    * @since Newzpaper 1.0.0
    * @param array $input tab section details.
    */
    function newzpaper_get_post_tab_section_details( $input ) {
        $options = newzpaper_get_theme_options();

        // Content type.
        $content = array();
        $args = array();
        $content['cats'] = array();

                $cat_ids = ! empty( $options['post_tab_category'] ) ? $options['post_tab_category'] : array();

                if ( empty( $cat_ids ) )
                    return;

                foreach ( $cat_ids as $cat_id ) :
                    $category_args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => -1,
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );
                    array_push( $args, $category_args );
                    array_push( $content['cats'], $cat_id );
                endforeach;               
                $content['taxonomy'] = 'category';

        $i = 0;
        foreach ( $args as $arg ) :
            $content['details'][$i] = array();
            // Run The Loop.
            $query = new WP_Query( $arg );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post[$i]['id']        = get_the_id();
                    $page_post[$i]['title']     = get_the_title();
                    $page_post[$i]['url']       = get_the_permalink();
                    $page_post[$i]['content']   = get_the_content();
                    $page_post[$i]['auth_id']   = get_the_author_meta('ID');
                    $page_post[$i]['excerpt']   = newzpaper_trim_content( 30 );
                    $page_post[$i]['image']      = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content['details'][$i], $page_post[$i] );
                endwhile;
            endif;
            wp_reset_postdata();
            $i++;
        endforeach;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// tab section content details.
add_filter( 'newzpaper_filter_post_tab_section_details', 'newzpaper_get_post_tab_section_details' );


if ( ! function_exists( 'newzpaper_render_post_tab_section' ) ) :
  /**
   * Start tab section
   *
   * @return string tab content
   * @since Newzpaper 1.0.0
   *
   */
   function newzpaper_render_post_tab_section( $content_details = array() ) {
        $options = newzpaper_get_theme_options();
        $tab_title = ! empty( $options['post_tab_title'] ) ? $options['post_tab_title'] : '';
        $tab_btn = ! empty( $options['post_tab_label'] ) ? $options['post_tab_label'] : '';
        
    ?>
    <div id="newzpaper_post_tab_section">
        <div id="newzpaper_magazine" class="relative home-section post-tab">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    newzpaper_section_tooltip( 'post-tab-class' );
                endif; ?>
                <?php if( !empty( $tab_title ) ): ?>
                    <div class="section-header">                    
                        <h2 class="section-title"><?php echo esc_html( $tab_title ); ?></h2>                    
                    </div><!-- .section-header -->
               <?php endif; ?>

               <div class="section-tabs">
                    <span><?php echo esc_html__( 'Categories:', 'newzpaper' ); ?></span>
                    <ul class="tabs">
                        <?php 
                        $count=0; foreach ( $content_details['cats'] as $i=>$content ) :
                            $terms =  get_term_by( 'id', $content, $content_details['taxonomy'] ); 
                            if(!is_wp_error( $terms ) && $terms): ?>
                                <li class= "<?php echo ( $count==0 ? 'active' : ''); ?>" data-tab="<?php echo esc_attr($terms->slug); ?>"><a href="#"><?php echo esc_html( $terms->name ); ?></a></li>
                            <?php endif;
                            $count++;
                        endforeach; ?>
                    </ul>
                </div>

                <div class="section-content">
                    
                    <?php foreach ( $content_details['details'] as $i => $content_detail ) :    
                        $catid =  $content_details['cats'][$i];
                        $cat = get_term_by( 'id', $catid, $content_details['taxonomy']); 
                    ?>

                        <div id="<?php echo esc_attr($cat->slug); ?>" class="tab-content <?php echo ( $i==0 ? 'active' : ''); ?>">
                            <div class="col-3">
                            <?php foreach ( $content_detail as $content ) : ?>
                                <?php
                                $terms_slugs_string = '';
                                                               
                                $terms = get_the_terms( $content['id'], $content_details['taxonomy'] );
                                if ( $terms && ! is_wp_error( $terms ) ) {                
                                    $term_slugs_array = array();
                                    foreach ( $terms as $term ) {
                                        $term_slugs_array[] = $term->slug;
                                    }
                                    $terms_slugs_string = join( ", ", $term_slugs_array );
                                    $terms_slugs_string_class = join( " ", $term_slugs_array );
                                }
                                ?>
                                <article class="magazine-match-height <?php echo esc_attr($terms_slugs_string_class); ?>">
                                    <div class="magazine-post-wrapper">
                                        <div class="entry-meta">
                                            <?php newzpaper_posted_on($content['id'] ); ?>
                                            <span class="cat-links">
                                              <?php the_category( '', '', $content['id'] ); ?>
                                          </span>
                                        </div>
                                        <div class="featured-image relative" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                            <div class="overlay"></div>
                                        </div><!-- .featured-image -->

                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                            </header>
                                            <div class="entry-content">
                                                <p><?php echo esc_html($content['excerpt']); ?></p>
                                            </div>
                                            <div class="post-meta">
                                                <?php echo newzpaper_author($content['auth_id'] ); ?>
                                                <span class="min-read"><span class="entry-meta-text"><?php echo esc_html__( 'Read: ', 'newzpaper' ); ?></span> <span><?php echo newzpaper_time_interval($content['content']); echo esc_html__(' min', 'newzpaper'); ?></span></span>
                                            </div>
                                        </div><!-- .entry-container -->
                                    </div>
                                </article>
                            <?php endforeach; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                    
                    
                    <?php if( !empty( $options['post_tab_btn_url'] ) && !empty( $tab_btn ) ): ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( $options['post_tab_btn_url'] ); ?>" ><?php echo esc_html( $tab_btn ); ?><i class="fa fa-arrow-right"></i></a>
                        </div><!-- .read-more -->
                <?php endif; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #newzpaper_tab_section -->
    </div>
        
    <?php }
endif;