<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */
if ( ! function_exists( 'newzpaper_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Newzpaper 1.0.0
    */
    function newzpaper_add_subscription_section() {
        $options = newzpaper_get_theme_options();

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'newzpaper_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
           return false;
        }

        // Render subscription section now.
        newzpaper_render_subscription_section();
    }
endif;

if ( ! function_exists( 'newzpaper_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Newzpaper 1.0.0
   *
   */
   function newzpaper_render_subscription_section() {
        if ( ! class_exists( 'Jetpack' ) ) {
           return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
               return;
        }
        $options = newzpaper_get_theme_options();

        $subscription_title             = ! empty( $options['subscription_title'] ) ? $options['subscription_title'] : '';
        $subscription_btn_label         = ! empty( $options['subscription_btn_label'] ) ? $options['subscription_btn_label'] : esc_html__( 'Subscribe Now', 'newzpaper' );
   
        ?>

        <div id="newzpaper_subscription_section">
        
          <div id="newzpaper_subscribe" class="relative home-section subscribe-us">
              <div class="wrapper">
               <?php if ( is_customize_preview()):
                  newzpaper_section_tooltip( 'subscribe-us-class' );
                  endif; ?>
                  <div class="subscribe-wrapper">
                      <?php if( !empty( $subscription_title ) ): ?>
                        <header class="entry-header">
                            <h2 class="entry-title"><?php echo esc_html( $subscription_title ); ?></h2>
                        </header>   
                      <?php endif; ?>  
                      <div class="subscribe-form-wrapper">
                        <div class="jetpack_subscription_widget">
                          <?php 
                          $subscribe_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $subscription_btn_label ) . '" show_subscribers_total="0"]';
                          echo do_shortcode( wp_kses_post( $subscribe_shortcode ) ); 
                          ?>

                      </div>
                    </div>              
                      
                  </div><!-- .subscribe-form-wrapper -->
              </div><!-- .wrapper -->
          </div><!-- #subscribe-us -->

        </div>

    <?php }
endif;