<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

$options = newzpaper_get_theme_options();


if ( ! function_exists( 'newzpaper_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Newzpaper 1.0.0
	 */
	function newzpaper_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'newzpaper_doctype', 'newzpaper_doctype', 10 );


if ( ! function_exists( 'newzpaper_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'newzpaper_before_wp_head', 'newzpaper_head', 10 );

if ( ! function_exists( 'newzpaper_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'newzpaper' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'newzpaper_page_start_action', 'newzpaper_page_start', 10 );

if ( ! function_exists( 'newzpaper_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'newzpaper_page_end_action', 'newzpaper_page_end', 10 );


if ( ! function_exists( 'newzpaper_header' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_header() {
		$options = newzpaper_get_theme_options();  
		get_template_part( 'template-parts/header/'.$options['header_design'] );
	}
endif;
add_action( 'newzpaper_header_action', 'newzpaper_header', 20 );


if ( ! function_exists( 'newzpaper_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'newzpaper_content_start_action', 'newzpaper_content_start', 10 );
if ( ! function_exists( 'newzpaper_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Newzpaper 1.0.0
     *
     */
    function newzpaper_header_image() {
        if ( newzpaper_is_frontpage() )
            return;
        $options = newzpaper_get_theme_options();  
        $header_image = get_header_image();
        if ( !$options['page_banner_header_image_enable'] ) {
        	if ( is_singular() ) :
	            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
	        endif;
        }
        
        $page_banner_wrapper_class = $options['page_banner_wrapper_enable'] ? 'wrapper' : '';
        ?>

        <div id="page-site-header" class="relative <?php echo $page_banner_wrapper_class ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php newzpaper_custom_header_banner_title(); ?>
                </header>
                <?php if ( $options['page_banner_breadcrumb_enable'] ): ?>
                	<?php newzpaper_add_breadcrumb(); ?>
                <?php endif ?>
                
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'newzpaper_header_image_action', 'newzpaper_header_image', 20 );

if ( ! function_exists( 'newzpaper_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Newzpaper 1.0.0
	 */
	function newzpaper_add_breadcrumb() {
		$options = newzpaper_get_theme_options();

		
		// Bail if Home Page.
		if ( newzpaper_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * newzpaper_simple_breadcrumb hook
				 *
				 * @hooked newzpaper_simple_breadcrumb -  10
				 *
				 */
				do_action( 'newzpaper_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;
if ( ! function_exists( 'newzpaper_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_content_end() {
		?>
			
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'newzpaper_content_end_action', 'newzpaper_content_end', 10 );

if ( ! function_exists( 'newzpaper_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_footer_start() {
		$options = newzpaper_get_theme_options();
		$footer_wrapper_class = $options['footer_wrapper_enable'] ? 'wrapper' : '';
		?>
		<footer id="colophon" class="site-footer <?php echo $footer_wrapper_class ?>" role="contentinfo">
		<?php
	}
endif;
add_action( 'newzpaper_footer', 'newzpaper_footer_start', 10 );

if ( ! function_exists( 'newzpaper_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_footer_site_info() {
		$options = newzpaper_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info">
            <div class="wrapper">
            	<?php if ( ! empty( $options['footer_image'] ) ) : ?>
	            	<span><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $options['footer_image'] ); ?>" alt="<?php bloginfo( 'name' ); ?>"></a></span>
	            <?php endif; ?>

                <span>
                	<?php 
                	echo newzpaper_santize_allow_tag( $copyright_text ); 
                	if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( ' | ' );
					}
                	?>
            	</span>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'newzpaper_footer', 'newzpaper_footer_site_info', 40 );



if ( ! function_exists( 'newzpaper_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_footer_end() {
		?>
		</footer>
		<?php
		$options  = newzpaper_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo newzpaper_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php
		endif;
	}
endif;
add_action( 'newzpaper_footer', 'newzpaper_footer_end', 100 );

if ( ! function_exists( 'newzpaper_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_loader() {
		$options = newzpaper_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo newzpaper_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'newzpaper_before_header', 'newzpaper_loader', 10 );

if ( ! function_exists( 'newzpaper_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Newzpaper 1.0.0
	 *
	 */
	function newzpaper_infinite_loader_spinner() { 
		$id = get_the_ID();
		$options = newzpaper_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( ! empty($id) ) {
				echo '<div class="blog-loader">' . newzpaper_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'newzpaper_infinite_loader_spinner_action', 'newzpaper_infinite_loader_spinner', 10 );
