<?php
/**
 * Header Two design template
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

$options = newzpaper_get_theme_options();
$header_txt_logo_extra = $options['header_txt_logo_extra']; 

if(!empty(get_option('timezone_string'))){
    $tz = new DateTimeZone(get_option('timezone_string'));
}else{
    if ( get_option('gmt_offset') !== '0' ) {
        $tz = new DateTimeZone(get_option('gmt_offset'));
    }else{
        $tz = new DateTimeZone('UTC');
    }           
}
$dt = new DateTime("now", $tz); 
$df = get_option('date_format'). ' '. get_option('time_format');
$date = $dt->format($df);

?>
<div class="main-header">
    <div id="top-navigation" class="relative topbar-two">
        <div class="wrapper">
            <nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="Top Menu">
                <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                    <?php
                    echo newzpaper_get_svg( array( 'icon' => 'menu' ) );
                    echo newzpaper_get_svg( array( 'icon' => 'close' ) );
                    ?>      
                </button>
                <?php  

                    wp_nav_menu( array(
                        'theme_location' => 'secondary',
                        'container' => false,
                        'menu_class' => 'menu nav-menu',
                        'menu_id' => 'secondary-menu',
                        'echo' => true,
                        'fallback_cb' => 'newzpaper_menu_fallback_cb',
                    ) );
                ?>

                <div class="site-branding-wrapper"> 
                    <div class="site-branding">
                        <?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
                            <div class="site-logo">
                                <?php the_custom_logo(); ?>
                            </div>
                        <?php } 
                        if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
                            <div id="site-details">
                                <?php
                                if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
                                    if ( newzpaper_is_latest_posts() || newzpaper_is_frontpage() ) : ?>
                                        <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                    <?php else : ?>
                                        <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                                    <?php
                                    endif;
                                } 
                                if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
                                    $description = get_bloginfo( 'description', 'display' );
                                    if ( $description || is_customize_preview() ) : ?>
                                        <p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
                                    <?php
                                    endif; 
                                }?>
                            </div>
                        <?php endif; ?>
                    </div><!-- .site-branding -->
                </div>  

                <div class="icon-wrapper">
                    <div class="contact-info">
                        <div class="entry-meta">
                            <span class="posted-on">
                                <?php echo $date; ?>
                            </span><!-- .posted-on -->
                        </div><!-- .entry-meta -->
                    </div>
                    <div class="social-icons">
                        <?php 
                            wp_nav_menu( array(
                                'theme_location' => 'social',
                                'container' => false,
                                'menu_class' => 'menu',
                                'echo' => true,
                                'fallback_cb' => 'newzpaper_menu_fallback_cb',
                                'depth' => 1,
                                'link_before' => '<span class="screen-reader-text">',
                                'link_after' => '</span>',
                            ) );
                        ?>
                    </div><!-- .social-icons -->
                </div><!-- .icon-wrapper -->
            </nav><!-- .main-navigation-->
        </div><!-- .wrapper -->
    </div>

    <header id="masthead" class="site-header header-three" role="banner">
        <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
            <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                <?php
                echo newzpaper_get_svg( array( 'icon' => 'menu' ) );
                echo newzpaper_get_svg( array( 'icon' => 'close' ) );
                ?>      
            </button>
            <?php 
                wp_nav_menu( array(
                    'theme_location' => 'primary',
                    'container' => 'div',
                    'menu_class' => 'menu nav-menu',
                    'menu_id' => 'primary-menu',
                    'echo' => true,
                ) );
            ?>
    </header><!-- #masthead -->
</div>
