<?php
/**
 * Header Three design template
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Newzpaper
 * @since Newzpaper 1.0.0
 */

$options = newzpaper_get_theme_options();
$header_txt_logo_extra = $options['header_txt_logo_extra']; 


if(!empty(get_option('timezone_string'))){
    $tz = new DateTimeZone(get_option('timezone_string'));
}else{
    if ( get_option('gmt_offset') !== '0' ) {
        $tz = new DateTimeZone(get_option('gmt_offset'));
    }else{
        $tz = new DateTimeZone('UTC');
    }           
}
$dt = new DateTime("now", $tz); 
$df = get_option('date_format'). ' '. get_option('time_format');
$date = $dt->format($df);


?>

<div id="top-navigation" class="relative">
    <div class="wrapper">
        <nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="Top Menu">
            <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                <?php
                echo newzpaper_get_svg( array( 'icon' => 'menu' ) );
                echo newzpaper_get_svg( array( 'icon' => 'close' ) );
                ?>      
            </button>
            <?php  

                wp_nav_menu( array(
                    'theme_location' => 'secondary',
                    'container' => false,
                    'menu_class' => 'menu nav-menu',
                    'menu_id' => 'secondary-menu',
                    'echo' => true,
                    'fallback_cb' => 'newzpaper_menu_fallback_cb',
                ) );
            ?>


            <div class="icon-wrapper">
                <div class="contact-info">
                    <div class="entry-meta">
                        <span class="posted-on">
                            <?php echo $date; ?>
                        </span><!-- .posted-on -->
                    </div><!-- .entry-meta -->
                </div>
                <div class="social-icons">
                    <?php 
                        wp_nav_menu( array(
                            'theme_location' => 'social',
                            'container' => false,
                            'menu_class' => 'menu',
                            'echo' => true,
                            'fallback_cb' => 'newzpaper_menu_fallback_cb',
                            'depth' => 1,
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                        ) );
                    ?>
                </div><!-- .social-icons -->
            </div><!-- .icon-wrapper -->
        </nav><!-- .main-navigation-->
    </div><!-- .wrapper -->
</div>
<header id="masthead" class="site-header header-two" role="banner">
    <div class="site-branding-container">
        <div class="header-image">
            <div class="header-overlay"></div>
            <div class="wrapper">
                <div class="site-branding-wrapper clear">
                    <div class="site-branding">
                        <?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
                            <div class="site-logo">
                                <?php the_custom_logo(); ?>
                            </div>
                        <?php } 
                        if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
                            <div id="site-details">
                                <?php
                                if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
                                    if ( newzpaper_is_latest_posts() || newzpaper_is_frontpage() ) : ?>
                                        <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                    <?php else : ?>
                                        <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                                    <?php
                                    endif;
                                } 
                                if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
                                    $description = get_bloginfo( 'description', 'display' );
                                    if ( $description || is_customize_preview() ) : ?>
                                        <p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
                                    <?php
                                    endif; 
                                }?>
                            </div>
                        <?php endif; ?>
                    </div><!-- .site-branding -->

                    <?php if ( !empty( $options['header_ads_image'] ) ): ?>
                        <div class="site-advertisement">
                            <a href="<?php echo esc_url( $options['header_ads_url'] ) ?>">
                                <img src="<?php echo esc_url( $options['header_ads_image'] ) ?>" alt="site-advertisement">
                            </a>
                        </div>
                    <?php endif ?>
                    
                </div><!-- .site-branding-wrapper  -->
            </div>
        </div><!-- .header-image -->

        <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
            <div class="wrapper">
                <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                    <?php
                        echo newzpaper_get_svg( array( 'icon' => 'menu' ) );
                        echo newzpaper_get_svg( array( 'icon' => 'close' ) );
                    ?>      
                </button>
                <?php 
                    $search = '';
                    if ( $options['header_search_enable'] ) :
                        $search = '<li class="main-navigation-search">';
                        $search .= get_search_form( $echo = false );
                        $search .= '</li>';
                    endif;

                    $home_icon = newzpaper_get_svg( array( 'icon' => 'home' ) );
                
                    wp_nav_menu( array(
                        'theme_location' => 'primary',
                        'container' => false,
                        'menu_class' => 'menu nav-menu',
                        'menu_id' => 'primary-menu',
                        'echo' => true,
                        'fallback_cb' => 'newzpaper_menu_fallback_cb',
                        'items_wrap' => '<ul id="%1$s" class="%2$s"><li class="home-icon"><a href='.esc_url( home_url( '/' ) ). '>'.$home_icon.'</li>%3$s' . $search . '</ul>',
                    ) );
                ?>
            </div><!-- .wrapper -->
        </nav>
    </div>
</header>

